```{include} build/README.md
```

```{toctree}
:hidden:

Overview <self>
api.rst
changelog.md
contributor_guide.md
Bug Report <https://github.com/matteosox/pysparkplug/issues/new/choose>
Feature Request <https://github.com/matteosox/pysparkplug/issues/new/choose>
GitHub <https://github.com/matteosox/pysparkplug>
PyPI <https://pypi.org/project/pysparkplug>
```
